==> clickhouse-cli-0.1.7.2.tar.gz: clickhouse-cli-0.1.7.2/clickhouse_cli/clickhouse/sqlparse_patch.py <==
from sqlparse import tokens


KEYWORDS = {
    'ADD': tokens.Keyword,
    'AFTER': tokens.Keyword,
    'ALL': tokens.Keyword,
    'ALTER': tokens.Keyword.DDL,
    'ARRAY': tokens.Keyword,
    'AS': tokens.Keyword,
    'ATTACH': tokens.Keyword.DDL,
    'BY': tokens.Keyword,
    'CASE': tokens.Keyword,
    'CHECK': tokens.Keyword.DDL,
    'COLUMN': tokens.Keyword,
    'COORDINATE': tokens.Keyword,
    'COPY': tokens.Keyword,
    'CREATE': tokens.Keyword.DDL,
    'DATABASE': tokens.Keyword,
    'DATABASES': tokens.Keyword,
    'DESC': tokens.Keyword,
    'DESCRIBE': tokens.Keyword.DDL,
    'DETACH': tokens.Keyword.DDL,
    'DISTINCT': tokens.Keyword,
    'DROP': tokens.Keyword.DDL,
    'ELSE': tokens.Keyword,
    'END': tokens.Keyword,
    'EXISTS': tokens.Keyword,
    'FETCH': tokens.Keyword,
    'FINAL': tokens.Keyword,
    'FORMAT': tokens.Keyword,
    'FREEZE': tokens.Keyword,
    'FROM': tokens.Keyword,
    'FULL': tokens.Keyword,
    'GLOBAL': tokens.Keyword,
    'GROUP': tokens.Keyword,
    'HAVING': tokens.Keyword,
    'INNER': tokens.Keyword,
    'INSERT': tokens.Keyword.DML,
    'INTO': tokens.Keyword,
    'JOIN': tokens.Keyword,
    'KEY': tokens.Keyword,
    'LEFT': tokens.Keyword,
    'LIKE': tokens.Keyword,
    'LIMIT': tokens.Keyword,
    'MATERIALIZED': tokens.Keyword,
    'MODIFY': tokens.Keyword,
    'NAME': tokens.Keyword,
    'NOT': tokens.Keyword,
    'ON': tokens.Keyword,
    'OPTIMIZE': tokens.Keyword.DDL,
    'ORDER': tokens.Keyword,
    'OUTER': tokens.Keyword,
    'PART': tokens.Keyword,
    'PARTITION': tokens.Keyword,
    'POPULATE': tokens.Keyword,
    'PREWHERE': tokens.Keyword,
    'PRIMARY': tokens.Keyword,
    'RENAME': tokens.Keyword.DDL,
    'RESHARD': tokens.Keyword,
    'SELECT': tokens.Keyword.DML,
    'SETTINGS': tokens.Keyword,
    'SHOW': tokens.Keyword.DDL,
    'TABLE': tokens.Keyword,
    'TABLES': tokens.Keyword,
    'TEMPORARY': tokens.Keyword,
    'THEN': tokens.Keyword,
    'TO': tokens.Keyword,
    'TOTALS': tokens.Keyword,
    'UNION': tokens.Keyword,
    'UNREPLICATED': tokens.Keyword,
    'USING': tokens.Keyword,
    'VALUES': tokens.Keyword,
    'VIEW': tokens.Keyword,
    'WHEN': tokens.Keyword,
    'WHERE': tokens.Keyword,
    'WITH': tokens.Keyword,
}

==> clickhouse-cli-0.1.9.2.tar.gz: clickhouse-cli-0.1.9.2/clickhouse_cli/clickhouse/sqlparse_patch.py <==
from sqlparse import tokens


KEYWORDS = {
    'ADD': tokens.Keyword,
    'AFTER': tokens.Keyword,
    'ALIAS': tokens.Keyword,
    'ALL': tokens.Keyword,
    'ALTER': tokens.Keyword.DDL,
    'AND': tokens.Keyword,
    'ANY': tokens.Keyword,
    'ARRAY': tokens.Keyword,
    'AS': tokens.Keyword,
    'ASC': tokens.Keyword.Order,
    'ATTACH': tokens.Keyword.DDL,
    'BETWEEN': tokens.Keyword,
    'BY': tokens.Keyword,
    'CASE': tokens.Keyword,
    'CAST': tokens.Keyword,
    'CHECK': tokens.Keyword.DDL,
    'COLUMN': tokens.Keyword,
    'COPY': tokens.Keyword,
    'CREATE': tokens.Keyword.DDL,
    'DATABASE': tokens.Keyword,
    'DATABASES': tokens.Keyword,
    'DEFAULT': tokens.Keyword,
    'DELETE': tokens.Keyword.DML,
    'DESC': tokens.Keyword,
    'DESCRIBE': tokens.Keyword.DDL,
    'DETACH': tokens.Keyword.DDL,
    'DISTINCT': tokens.Keyword,
    'DROP': tokens.Keyword.DDL,
    'ELSE': tokens.Keyword,
    'END': tokens.Keyword,
    'ENGINE': tokens.Keyword,
    'EXISTS': tokens.Keyword,
    'FALSE': tokens.Keyword,
    'FETCH': tokens.Keyword,
    'FINAL': tokens.Keyword,
    'FIRST': tokens.Keyword,
    'FORMAT': tokens.Keyword,
    'FREEZE': tokens.Keyword,
    'FROM': tokens.Keyword,
    'FULL': tokens.Keyword,
    'GLOBAL': tokens.Keyword,
    'GROUP': tokens.Keyword,
    'HAVING': tokens.Keyword,
    'IF': tokens.Keyword,
    'IN': tokens.Keyword,
    'INNER': tokens.Keyword,
    'INSERT': tokens.Keyword.DML,
    'INTO': tokens.Keyword,
    'IS': tokens.Keyword,
    'JOIN': tokens.Keyword,
    'KEY': tokens.Keyword,
    'LEFT': tokens.Keyword,
    'LIKE': tokens.Keyword,
    'LIMIT': tokens.Keyword,
    'MATERIALIZED': tokens.Keyword,
    'MODIFY': tokens.Keyword,
    'NAME': tokens.Keyword,
    'NOT': tokens.Keyword,
    'OF': tokens.Keyword,
    'ON': tokens.Keyword,
    'OPTIMIZE': tokens.Keyword.DDL,
    'OR': tokens.Keyword,
    'ORDER': tokens.Keyword,
    'OUTER': tokens.Keyword,
    'OUTFILE': tokens.Keyword,
    'PART': tokens.Keyword,
    'PARTITION': tokens.Keyword,
    'POPULATE': tokens.Keyword,
    'PREWHERE': tokens.Keyword,
    'PRIMARY': tokens.Keyword,
    'RENAME': tokens.Keyword.DDL,
    'RESHARD': tokens.Keyword,
    'RIGHT': tokens.Keyword,
    'SELECT': tokens.Keyword.DML,
    'SET': tokens.Keyword,
    'SET': tokens.Keyword.DDL,
    'SETTINGS': tokens.Keyword,
    'SHOW': tokens.Keyword.DDL,
    'TABLE': tokens.Keyword,
    'TABLES': tokens.Keyword,
    'TEMPORARY': tokens.Keyword,
    'THEN': tokens.Keyword,
    'TO': tokens.Keyword,
    'TOTALS': tokens.Keyword,
    'UNION': tokens.Keyword,
    'UNREPLICATED': tokens.Keyword,
    'USE': tokens.Keyword.DDL,
    'USING': tokens.Keyword,
    'VALUES': tokens.Keyword,
    'VIEW': tokens.Keyword,
    'WHEN': tokens.Keyword,
    'WHERE': tokens.Keyword,
    'WITH': tokens.Keyword,
}
